%%%%%%%%%%%%%%%%%%%% Identification Part

\NeedsTeXFormat{LaTeX2e}[1993/11/11]

\ProvidesClass{these}[%
         1999/01/04 by Christian Perez, %
modified 2001/05/20 by Gabriel Antoniu, %
modified 2002/03/03 by Olivier Aumage]

%%%%%%%%%%%%%%%%%%% Special Class file commands

\LoadClass[11pt,a4paper]{mybook}
%\LoadClass[12pt,a4paper,twoside]{book}

%%%%%%%%%%%%%%%%%%% Initial code

%
%
% __ Inclusion of packages ___________________________________________

% Page dimensions
\usepackage[headings]{fullpage}

% Fonts
\usepackage{palatino}

% Fx objects
\usepackage{shadow}
\usepackage{ulem}

% Special text environments
\usepackage{enumerate}
\usepackage{verbatim}
\usepackage{moreverb}
%\usepackage{alltt}
\usepackage{fancyvrb}
%\usepackage{fancyhdr}

% Arrays
\usepackage{multirow}
\usepackage{array}

% Programming tools
\usepackage{xspace}
\usepackage{ifthen}
\usepackage{calc}

% Gray levels management
\usepackage{color}

% Bibliographie
\usepackage{bibtopic}
\usepackage{frbib}

% Mathematiques
\usepackage{amsfonts,amsmath,amssymb,amsthm,amstext,latexsym,stmaryrd,wasysym}

\AtBeginDocument{%
  \theoremstyle{plain}
  \newtheorem{lemma}{Lemme}[chapter]
  \newtheorem{theorem}{Thorme}[chapter]
  \newtheorem{proposition}{Proposition}[chapter]
  \newtheorem{corollary}{Corollaire}[chapter]
  \newtheorem{definition}{Dfinition}[chapter]
  \newtheorem*{property}{Proprit}
  \newtheorem{remark}{Remarque}[chapter]
}

\AtBeginDocument{%
  \renewcommand{\qedsymbol}{$\blacksquare$}
  \renewcommand{\proofname}{Dmonstration}%
}

%%%%%%%%%%%%%%%%%%%%%%%% Pour les algorithmes %%%%%%%%%%%%%%%%%%%%%%%%

%
%
% __ Setup of packages _______________________________________________

% Ulem
\normalem

% FancyVrb
\fvset{numbers=left}
\fvset{numbersep=2pt}
%\fvset{obeytabs=true}
\fvset{obeytabs=false}
\fvset{resetmargins=true}
\fvset{frame=lines}
\fvset{framerule=0mm}
\fvset{framesep=1mm}


% ____________________________________________________________________

\def\PBS#1{\let\temp=\\#1\let\\=\temp}

%\pagenumbering{roman}
%\pagestyle{plain}


%%%%%%%%%%%%%%%%%%%% Declaration of Options

% none

%%%%%%%%%%%%%%%%%%%% Execution of Options

\ProcessOptions

%%%%%%%%%%%%%%%%%%% Special Commands

\AtBeginDocument{
\sloppy
\selectlanguage{francais}
\AutoSpaceBeforeFDP
\setlength{\parskip}{0.3\baselineskip plus 0.2\baselineskip}
}

\AtEndDocument{}

%%%%%%%%%%%%%%%% Style Definition

%
%
% __ Settings ________________________________________________________

%\setcounter{tocdepth}{4}    % -> paragraph
\setcounter{tocdepth}{2}    % -> subsection
\setcounter{secnumdepth}{3} % -> subsubsection


%
%
% __ Macros __________________________________________________________

%
% ____ Realistic listings ............................................
%\usepackage{pretty_listings}

% ...... Background grays ............................................
\definecolor{light}{gray}{.85}
\definecolor{vlight}{gray}{.95}

% ...... Aux. objects ................................................
\newcounter{mylstline}
\newlength{\mylstlength}
%
% ____ Extended description lists ....................................
\usepackage{desclist}

% ____________________________________________________________________

%%% Sections redefinitions


% Compteur pour la partie 'rfrences'
\newcounter{mybibcnt}
\setcounter{mybibcnt}{1}

\newcommand{\mybibitem}[1]{%
  \bibitem[{\texttt{\Alph{mybibcnt}}}]{#1}\stepcounter{mybibcnt}%
}

\newcommand{\newdoublepage}{\newpage\cleardoublepage}

\newenvironment{noparskip}{\bgroup\parskip=0pt}
{\egroup}

%%%%%%%%%%%%%%%% Name Definition

\newcommand{\mycite}[1]{[\Alph{#1}]}

\newcommand{\entree}[1]{%
\hspace{-3mm}\begin{minipage}[t]{7mm}%
\raggedleft \mycite{theentree}
%
\end{minipage}%
\rule{1mm}{0pt}
\begin{minipage}[t]{0.92\textwidth}%
#1%
\end{minipage}%
\vspace{3mm}%
\stepcounter{theentree}
}

\newcommand{\titre}[1]{%
\vspace{9mm}
{\Large\em #1}\vspace{-2.5mm}\\%
\noindent\rule{6mm}{0pt}\rule{0.96\textwidth}{1pt}
\vspace{2mm}
}


%_____________________________________________________________________
